OiRA

Help

1. Подготовка
2. Включване
3. Определяне + Оценяване
4. План за действие
5. Доклад
6. Статус 37%

# Статус на Commercial guarding, Leicester

## Обща информация

Използван инструмент

  Commercial guarding, Leicester

публикуван

  5 August 2017 by angela.baumeister@company.com

запазено

  7 June 2018 by hans.mittelmaier@company.com

## Въпроси, на които е отговорено, за модул

Commercial manned guarding - Abby Road

  1 question answered without a risk

  3 answers indicated a risk and have at least one measure defined in the action plan

  2 answers indicated a risk without any measure defined in the action plan

  2 questions were postponed

  2 questions aren't answered yet

  - 1 Правилно
  - 3
  - 2 Внимание
  - 2 Отложено разглеждане
  - 2 Без отговор

  #### Високо приоритетен риск

  - Lorem ipsum
  - Dolor sit amet
  - Consectetuer vadifrimulus automobilis
Mobile partrolling/intervention after alarm

  7 Без отговор

  1

  1 Внимание

  1 Отложено разглеждане

  - 7 Без отговор
  - 1
  - 1 Внимание
  - 1 Отложено разглеждане

  #### High priority risks

  - Lorem ipsum
  - Dolor sit amet
  - Consectetuer vadifrimulus automobilis

Scroll to top
Back

## status.html

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More